#include <cstdio>
#include <cassert>
#include <cmath>
#include <map>
#include <algorithm>
#include <queue>
using namespace std;
 
typedef pair<int, int> pii;
#define px first
#define py second
 
int N, M;
pii node[10000], edge[30000], sedge[60000], faces[60000];
int facecnt, facestart[10000], outerface, ds[10000], faceblank[10000];
map<pii, int> colour, faceid;
map<pii, pii> nextccw;
 
double angle(const pii &p1, const pii &p2){
	return atan2(p2.py-p1.py, p2.px-p1.px);
}
 
pii rev(const pii &p){
	return make_pair(p.second, p.first);
}
 
long long trapezoid(const pii &p1, const pii &p2){
	return (long long)(p2.px-p1.px)*(p2.py+p1.py);
}
 
bool edgecmp(const pii &e1, const pii &e2){
	if(e1.first<e2.first)
		return true;
	else if(e2.first<e1.first)
		return false;
	return angle(node[e1.first], node[e1.second])<angle(node[e2.first], node[e2.second]);
}
 
int ds_find(int i, int *p){
	if(p[i]==i)
		return i;
	p[i]=ds_find(p[i], p);
	return p[i];
}
 
bool ds_union(int i, int j, int *p){
	i=ds_find(i, p);
	j=ds_find(j, p);
	if(i!=j)
		p[i]=j;
	return i!=j;
}
 
void read(){
	nextccw.clear();
	colour.clear();
	faceid.clear();
	scanf("%d %d", &N, &M);
	for(int i=0; i<N; i++)
		scanf("%d %d", &node[i].px, &node[i].py);
	for(int i=0; i<M; i++){
		scanf("%d %d", &edge[i].first, &edge[i].second);
		sedge[i]=edge[i];
		sedge[i+M]=rev(edge[i]);
	}
	sort(sedge, sedge+2*M, edgecmp);
	int pos=0;
	for(int i=0; i<N; i++){
		int first;
		for(first=pos++; pos<2*M && sedge[pos].first==i; pos++)
			nextccw[sedge[pos-1]]=sedge[pos];
		nextccw[sedge[pos-1]]=sedge[first];
	}
	facecnt=0;
	int facepos=0;
	outerface=-1;
	for(int i=0; i<2*M; i++){
		if(colour.count(sedge[i]))
			continue;
		facestart[facecnt]=facepos;
		pii start=sedge[i];
		pii cur=start;
		long long area=0;
		do{
			assert(!colour.count(cur));
			colour[cur]=-1;
			faces[facepos++]=cur;
			area+=trapezoid(node[cur.first], node[cur.second]);
			faceid[cur]=facecnt;
			cur=nextccw[rev(cur)];
		}while(cur!=start);
		assert(area!=0);
		if(area<0){
			assert(outerface==-1);
			outerface=facecnt;
		}
		faceblank[facecnt]=facepos-facestart[facecnt];
		facecnt++;
	}
	assert(outerface!=-1);
	assert(facepos==2*M);
	facestart[facecnt]=facepos;
}
 
void solve(){
	for(int i=0; i<N; i++)
		ds[i]=i;
	queue<int> facequeue;
	for(int i=0; i<M; i++){
		if(ds_union(edge[i].first, edge[i].second, ds)){
			colour[edge[i]]=colour[rev(edge[i])]=0;
			if(--faceblank[faceid[edge[i]]]==1)
				facequeue.push(faceid[edge[i]]);
			if(--faceblank[faceid[rev(edge[i])]]==1)
				facequeue.push(faceid[rev(edge[i])]);
		}
	}
	assert(!facequeue.empty());
	for(; !facequeue.empty(); facequeue.pop()){
		int face=facequeue.front();
		if(face==outerface)
			continue;
		int parity=1;
		int missing=-1;
		for(int i=facestart[face]; i<facestart[face+1]; i++){
			if(colour[faces[i]]==-1){
				assert(missing==-1);
				missing=i;
			}else
				parity^=colour[faces[i]];
		}
		assert(missing!=-1);
		colour[faces[missing]]=colour[rev(faces[missing])]=parity;
		if(--faceblank[faceid[rev(faces[missing])]]==1)
			facequeue.push(faceid[rev(faces[missing])]);
	}
}
 
void print(){
	for(int i=0; i<M; i++){
		assert(colour[edge[i]]!=-1);
		printf("%d ", colour[edge[i]]);
	}
	putchar('\n');
}
 
int main(){
	int T;
	scanf("%d", &T);
	while(T--){
		read();
		solve();
		print();
	}
	return 0;
}
 